@@ -317,18 +317,65 @@ out:
 	return(0);
 }
 
+// Based on the output of ls(1p).
+static char file_type_to_char(mode_t mode) {
+	char ftype = '?';
+	if (S_ISREG(mode))
+		ftype = '-';
+	else if (S_ISDIR(mode))
+		ftype = 'd';
+	else if (S_ISLNK(mode))
+		ftype = 'l';
+	else if (S_ISCHR(mode))
+		ftype = 'c';
+	else if (S_ISBLK(mode))
+		ftype = 'b';
+	else if (S_ISFIFO(mode))
+		ftype = 'p';
+	else if (S_ISSOCK(mode))
+		ftype = 's';
+
+	return ftype;
+}
 
 static char *check(const char *src) {
-	struct stat s;
 	char *rsrc = realpath(src, NULL);
-	if (!rsrc || stat(rsrc, &s) == -1)
-		goto errexit;
+	if (!rsrc) {
+		fprintf(stderr, "Error fcopy: realpath %s\n", src);
+		errExit("realpath");
+	}
+	struct stat s;
+	if (stat(rsrc, &s) == -1) {
+		fprintf(stderr, "Error fcopy: stat %s -> %s\n", src, rsrc);
+		errExit("stat");
+	}
+	struct passwd *src_pw = getpwuid(s.st_uid);
+	if (!src_pw) {
+		fprintf(stderr, "Error fcopy: getpwuid %s -> %s\n", src, rsrc);
+		errExit("getpwuid");
+	}
+
+	uid_t src_uid = src_pw->pw_uid;
+	char *src_username = strdup(src_pw->pw_name);
+	if (!src_username)
+		errExit("strdup");
 
-	// on systems with systemd-resolved installed /etc/resolve.conf is a symlink to
-	//    /run/systemd/resolve/resolv.conf; this file is owned by systemd-resolve user
-	// checking gid will fail for files with a larger group such as /usr/bin/mutt_dotlock
 	uid_t user = getuid();
-	if (user == 0 && strncmp(rsrc, "/run/systemd/resolve/", 21) == 0) {
+	char ftype = file_type_to_char(s.st_mode);
+
+	// Note: Checking gid will fail for files with a larger group, such as
+	// /usr/bin/mutt_dotlock (see #1243).
+	if (s.st_uid == user) {
+		// ok
+	}
+	// The following are the allowed exceptions (see #1531).
+
+	// On systems using systemd-resolved, /etc/resolve.conf may be owned by
+	// the "systemd-resolve" user and may be a regular file or a symlink to
+	// /run/systemd/resolve/resolv.conf (see #4545).
+	else if (user == 0 &&
+			((strcmp(rsrc, "/etc/resolv.conf") == 0) ||
+			(strncmp(rsrc, "/run/systemd/resolve/", 21) == 0))) {
 		// check user systemd-resolve
 		struct passwd *p = getpwnam("systemd-resolve");
 		if (!p)
@@ -336,18 +383,33 @@ static char *check(const char *src) {
 		if (s.st_uid != user && s.st_uid != p->pw_uid)
 			goto errexit;
 	}
+	// Some system paths may be owned by "runner:root" on GitHub Actions
+	// runner images (see #6797), such as the following pointed-to path:
+	//
+	//     /etc/localtime -> /usr/share/zoneinfo/Etc/UTC
+	else if (user == 0 &&
+			(strncmp(rsrc, "/usr/share/", 11) == 0) &&
+			(strncmp(src_username, "runner", 6) == 0)) {
+		fprintf(stderr, "Warning fcopy: ignoring path for CI: %s -> %s (type=%c uid=%lu, name=%s)\n",
+		        src, rsrc, ftype, (unsigned long)src_uid, src_username);
+	}
 	else {
-		if (s.st_uid != user)
-			goto errexit;
+		goto errexit;
 	}
 
 	// dir, link, regular file
-	if (S_ISDIR(s.st_mode) || S_ISREG(s.st_mode) || S_ISLNK(s.st_mode))
+	if (S_ISDIR(s.st_mode) || S_ISREG(s.st_mode) || S_ISLNK(s.st_mode)) {
+		free(src_username);
 		return rsrc;			  // normal exit from the function
+	}
+
+	fprintf(stderr, "Error fcopy: invalid file type for %s -> %s (type=%c uid=%lu name=%s)\n",
+	        src, rsrc, ftype, (unsigned long)src_uid, src_username);
+	exit(1);
 
 errexit:
-	free(rsrc);
-	fprintf(stderr, "Error fcopy: invalid ownership for file %s\n", src);
+	fprintf(stderr, "Error fcopy: invalid ownership for %s -> %s (type=%c uid=%lu name=%s)\n",
+	        src, rsrc, ftype, (unsigned long)src_uid, src_username);
 	exit(1);
 }
 
