@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -197,7 +197,11 @@ int arp_check(const char *dev, uint32_t destaddr) {
 		double timeout = timerend - now;
 		ts.tv_sec = timeout;
 		ts.tv_usec = (timeout - ts.tv_sec) * 1000000;
-		int nready = select(maxfd + 1,  &fds, (fd_set *) 0, (fd_set *) 0, &ts);
+		if (ts.tv_sec < 0)
+			ts.tv_sec = 0;
+		if (ts.tv_usec < 0)
+			ts.tv_usec = 0;
+		int nready = select(maxfd + 1, &fds, (fd_set *) 0, (fd_set *) 0, &ts);
 		if (nready < 0)
 			errExit("select");
 		else if (nready == 0) { // timeout
@@ -299,7 +303,7 @@ static uint32_t arp_random(const char *dev, Bridge *br) {
 	return 0;
 }
 
-// go sequentially trough all IP addresses and assign the first one not in use
+// go sequentially through all IP addresses and assign the first one not in use
 static uint32_t arp_sequential(const char *dev, Bridge *br) {
 	assert(dev);
 	assert(br);
