@@ -116,6 +116,7 @@ int arg_doubledash = 0;			// double dash
 int arg_private_dev = 0;			// private dev directory
 int arg_keep_dev_ntsync = 0;			// preserve /dev/ntsync
 int arg_keep_dev_shm = 0;			// preserve /dev/shm
+int arg_keep_dev_tpm = 0;			// preserve /dev/tpm*
 int arg_private_etc = 0;			// private etc directory
 int arg_private_opt = 0;			// private opt directory
 int arg_private_srv = 0;			// private srv directory
@@ -156,7 +157,6 @@ int arg_noprofile = 0; // use default.profile if none other found/specified
 int arg_memory_deny_write_execute = 0;		// block writable and executable memory
 int arg_notv = 0;	// --notv
 int arg_nodvd = 0; // --nodvd
-int arg_notpm = 0; // --notpm
 int arg_nou2f = 0; // --nou2f
 int arg_noinput = 0; // --noinput
 int arg_deterministic_exit_code = 0;	// always exit with first child's exit status
@@ -2040,6 +2040,9 @@ int main(int argc, char **argv, char **envp) {
 		else if (strcmp(argv[i], "--keep-dev-shm") == 0) {
 			arg_keep_dev_shm = 1;
 		}
+		else if (strcmp(argv[i], "--keep-dev-tpm") == 0) {
+			arg_keep_dev_tpm = 1;
+		}
 		else if (strcmp(argv[i], "--private-etc") == 0) {
 			if (checkcfg(CFG_PRIVATE_ETC)) {
 				if (arg_writable_etc) {
@@ -2224,8 +2227,9 @@ int main(int argc, char **argv, char **envp) {
 			arg_notv = 1;
 		else if (strcmp(argv[i], "--nodvd") == 0)
 			arg_nodvd = 1;
+		// TODO: Fully remove notpm after 0.9.76.
 		else if (strcmp(argv[i], "--notpm") == 0)
-			arg_notpm = 1;
+			fwarning("ignoring removed command: --notpm (see --keep-dev-tpm)\n");
 		else if (strcmp(argv[i], "--nou2f") == 0)
 			arg_nou2f = 1;
 		else if (strcmp(argv[i], "--noinput") == 0)
@@ -3239,6 +3243,15 @@ int main(int argc, char **argv, char **envp) {
 				}
 			}
 
+			// add tss group
+			if (arg_keep_dev_tpm) {
+				g = get_group_id("tss");
+				if (g) {
+					sprintf(ptr, "%d %d 1\n", g, g);
+					ptr += strlen(ptr);
+				}
+			}
+
 			// add plugdev group
 			if (!arg_nou2f) {
 				g = get_group_id("plugdev");
