@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -65,7 +65,7 @@ void netfilter_netlock(pid_t pid) {
 			umask(orig_umask);
 
 			char *cmd;
-			if (asprintf(&cmd, "%s -e \"%s/firejail/fnettrace --tail --log=%s\"", terminal, LIBDIR, flog) == -1)
+			if (asprintf(&cmd, "%s -e \"%s/firejail/fnetlock --tail --log=%s\"", terminal, LIBDIR, flog) == -1)
 				errExit("asprintf");
 			int rv = system(cmd);
 			(void) rv;
@@ -74,7 +74,7 @@ void netfilter_netlock(pid_t pid) {
 	}
 
 	char *cmd;
-	if (asprintf(&cmd, "%s/firejail/fnettrace --netfilter --log=%s", LIBDIR, flog) == -1)
+	if (asprintf(&cmd, "%s/firejail/fnetlock --log=%s", LIBDIR, flog) == -1)
 		errExit("asprintf");
 	free(flog);
 
@@ -108,7 +108,7 @@ void netfilter_trace(pid_t pid, const char *cmd) {
 	arg[3] = NULL;
 
 	clearenv();
-	sbox_exec_v(SBOX_ROOT | SBOX_CAPS_NETWORK | SBOX_SECCOMP, arg);
+	sbox_exec_v(SBOX_ROOT | SBOX_CAPS_NETWORK | SBOX_SECCOMP | SBOX_ALLOW_STDIN, arg);
 	// it will never get here!!
 }
 
@@ -248,5 +248,5 @@ void netfilter_print(pid_t pid, int ipv6) {
 		exit(1);
 	}
 
-	sbox_run(SBOX_ROOT | SBOX_CAPS_NETWORK | SBOX_SECCOMP, 2, iptables, "-vL");
+	sbox_run(SBOX_ROOT | SBOX_CAPS_NETWORK | SBOX_SECCOMP, 2, iptables, "-nvL");
 }
