@@ -295,6 +295,11 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+	if (strncmp(ptr, "warn ", 5) == 0) {
+		fwarning("%s:%d: %s\n", fname, lineno, ptr + 5);
+		return 0;
+	}
+
 	if (strncmp(ptr, "keep-fd ", 8) == 0) {
 		if (strcmp(ptr + 8, "all") == 0)
 			arg_keep_fd_all = 1;
@@ -439,6 +444,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		arg_keep_dev_shm = 1;
 		return 0;
 	}
+	else if (strcmp(ptr, "keep-dev-tpm") == 0) {
+		arg_keep_dev_tpm = 1;
+		return 0;
+	}
 	else if (strcmp(ptr, "private-tmp") == 0) {
 		arg_private_tmp = 1;
 		return 0;
@@ -622,8 +631,9 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 #endif
 		return 1;
 	}
+	// TODO: Fully remove notpm after 0.9.76.
 	else if (strcmp(ptr, "notpm") == 0) {
-		arg_notpm = 1;
+		fwarning("ignoring removed command: notpm (see keep-dev-tpm)\n");
 		return 0;
 	}
 	else if (strcmp(ptr, "nou2f") == 0) {
