@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2022 Firejail Authors
+ * Copyright (C) 2014-2025 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -210,9 +210,9 @@ static void sanitize_passwd(void) {
 			goto errout;
 
 		// process uid
-		int uid;
+		int uid = -1;
 		int rv = sscanf(ptr, "%d:", &uid);
-		if (rv == 0 || uid < 0)
+		if (rv != 1 || uid < 0)
 			goto errout;
 		assert(uid_min);
 		if (uid < uid_min || uid == 65534) { // on Debian platforms user nobody is 65534
@@ -234,7 +234,7 @@ static void sanitize_passwd(void) {
 	SET_PERMS_STREAM(fpout, 0, 0, 0644);
 	fclose(fpout);
 
-	// mount-bind tne new password file
+	// mount-bind the new password file
 	if (mount(RUN_PASSWD_FILE, "/etc/passwd", "none", MS_BIND, "mode=400,gid=0") < 0)
 		errExit("mount");
 
@@ -349,9 +349,9 @@ static void sanitize_group(void) {
 			goto errout;
 
 		// process uid
-		int gid;
+		int gid = -1;
 		int rv = sscanf(ptr, "%d:", &gid);
-		if (rv == 0 || gid < 0)
+		if (rv != 1 || gid < 0)
 			goto errout;
 		assert(gid_min);
 		if (gid < gid_min || gid == 65534) { // on Debian platforms 65534 is group nogroup
@@ -369,7 +369,7 @@ static void sanitize_group(void) {
 	SET_PERMS_STREAM(fpout, 0, 0, 0644);
 	fclose(fpout);
 
-	// mount-bind tne new group file
+	// mount-bind the new group file
 	if (mount(RUN_GROUP_FILE, "/etc/group", "none", MS_BIND, "mode=400,gid=0") < 0)
 		errExit("mount");
 
