@@ -1,6 +1,6 @@
 #!/bin/bash
 # This file is part of Firejail project
-# Copyright (C) 2014-2022 Firejail Authors
+# Copyright (C) 2014-2025 Firejail Authors
 # License GPL v2
 
 export MALLOC_CHECK_=3
@@ -13,12 +13,12 @@ if [[ -f /etc/debian_version ]]; then
 fi
 export PATH="$PATH:/usr/lib/firejail:/usr/lib64/firejail"
 
-if [[ -f /sys/kernel/security/apparmor/profiles ]]; then
-	echo "TESTING: apparmor (test/filters/apparmor.exp)"
-	./apparmor.exp
-else
-	echo "TESTING SKIP: no apparmor support in Linux kernel (test/filters/apparmor.exp)"
-fi
+#if [[ -f /sys/kernel/security/apparmor/profiles ]]; then
+#	echo "TESTING: apparmor (test/filters/apparmor.exp)"
+#	./apparmor.exp
+#else
+#	echo "TESTING SKIP: no apparmor support in Linux kernel (test/filters/apparmor.exp)"
+#fi
 
 if [[ $(uname -m) == "x86_64" ]]; then
 	echo "TESTING: memory-deny-write-execute (test/filters/memwrexe.exp)"
@@ -53,22 +53,19 @@ fi
 echo "TESTING: seccomp postexec (test/filters/seccomp-postexec.exp)"
 ./seccomp-postexec.exp
 
-echo "TESTING: noroot (test/filters/noroot.exp)"
-./noroot.exp
 
-
-if grep -q "^CapBnd:\\s0000003fffffffff" /proc/self/status; then
-	echo "TESTING: capabilities (test/filters/caps.exp)"
-	./caps.exp
-else
-	echo "TESTING SKIP: other capabilities than expected (test/filters/caps.exp)"
-fi
-
-echo "TESTING: capabilities print (test/filters/caps-print.exp)"
-./caps-print.exp
-
-echo "TESTING: capabilities join (test/filters/caps-join.exp)"
-./caps-join.exp
+#if grep -q "^CapBnd:\\s0000003fffffffff" /proc/self/status; then
+#	echo "TESTING: capabilities (test/filters/caps.exp)"
+#	./caps.exp
+#else
+#	echo "TESTING SKIP: other capabilities than expected (test/filters/caps.exp)"
+#fi
+#
+#echo "TESTING: capabilities print (test/filters/caps-print.exp)"
+#./caps-print.exp
+#
+#echo "TESTING: capabilities join (test/filters/caps-join.exp)"
+#./caps-join.exp
 
 rm -f seccomp-test-file
 if [[ $(uname -m) == "x86_64" ]]; then
